//
//  ExtraParamVC.m
//  PokktAdsDemo
//
//  Created by Suraj Singh on 27/09/17.
//  Copyright © 2017 Pokkt. All rights reserved.
//

#import "ExtraParamVC.h"

@interface ExtraParamVC ()
@property (weak, nonatomic) IBOutlet UIButton *addParamsBtn;
@property (weak, nonatomic) IBOutlet UIScrollView *scrollView;
@property (weak, nonatomic) IBOutlet UIButton *sendBtn;
@property (weak, nonatomic) IBOutlet UIButton *resetParamsBtn;

@property (nonatomic) int yAxes;

@end

@implementation ExtraParamVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    logoImgV.transform = CGAffineTransformMakeRotation(-M_1_PI);
    
    [self.addParamsBtn.layer setBorderColor:[UIColor darkGrayColor].CGColor];
    [self.addParamsBtn.layer setBorderWidth:1];
    
    [self.resetParamsBtn.layer setBorderColor:[UIColor darkGrayColor].CGColor];
    [self.resetParamsBtn.layer setBorderWidth:1];
    
    [self.sendBtn.layer setBorderColor:[UIColor darkGrayColor].CGColor];
    [self.sendBtn.layer setBorderWidth:1];
    
    self.yAxes = 5;
    [self setUpConstraints];
}

-(void)viewDidAppear:(BOOL)animated
{
    NSUserDefaults *preferences = [NSUserDefaults standardUserDefaults];
    NSDictionary *dict = [preferences objectForKey:@"extraParam"];
    if (dict != nil && dict.count > 0)
    {
        for(NSString *key in dict.allKeys)
        {
            [self createExtraParamForm:key andValue:[dict objectForKey:key]];
        }
    }
}

-(void)viewWillDisappear:(BOOL)animated
{
    if ([self getUserEnteredData] != nil && [[self getUserEnteredData] count] > 0)
    {
        NSUserDefaults *preferences = [NSUserDefaults standardUserDefaults];
        [preferences setObject:[self getUserEnteredData] forKey:@"extraParam"];
        [preferences synchronize];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
- (IBAction)addExtraParam:(id)sender
{
    [self createExtraParamForm:@"" andValue:@""];
}
- (IBAction)resetAllParam:(id)sender
{
   for(UIView *subView in self.scrollView.subviews)
   {
       [subView removeFromSuperview];
   }
    NSUserDefaults *preferences = [NSUserDefaults standardUserDefaults];
    [preferences removeObjectForKey:@"extraParam"];
   self.yAxes = 5;
}

- (IBAction)sendAction:(id)sender
{
//    if ([self getUserEnteredData] != nil && [[self getUserEnteredData] count] > 0)
//    {
//        [PokktAds setCallbackExtraParam:[self getUserEnteredData]];
//    }
    
    [self.navigationController dismissViewControllerAnimated:YES completion:nil];
}

-(NSDictionary *)getUserEnteredData
{
    NSMutableDictionary *extraParam = [[NSMutableDictionary alloc] init];
    
    for(UIView *subView in [self.scrollView subviews])
    {
        NSString *keyParam = @"";
        NSString *valueParam = @"";
        for(UITextField *tf in subView.subviews)
        {
            NSString *placeHolder = tf.placeholder;
            
            if (placeHolder != nil && [placeHolder isEqualToString:@"Key"])
            {
                keyParam = tf.text;
            }
            else if (placeHolder != nil && [placeHolder isEqualToString:@"Value"])
            {
                valueParam = tf.text;
            }
        }
        if (keyParam != nil && keyParam.length > 0) {
            [extraParam setObject:valueParam forKey:keyParam];
        }
    }
    
    return extraParam;
}


-(void)createExtraParamForm:(NSString *)key andValue:(NSString *)value
{
    UIView *containerView = [[UIView alloc] init];
    [containerView setBackgroundColor:[UIColor clearColor]];
    [self.scrollView addSubview:containerView];
    
    [containerView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(self.scrollView.mas_left).with.offset(5);
        make.top.equalTo(self.scrollView.mas_top).with.offset(self.yAxes);
        make.right.equalTo(self.view.mas_right).with.offset(-7);
        make.height.equalTo(@33);
    }];
    
    UITextField *keyTF = [[UITextField alloc] init];
    [keyTF setPlaceholder:@"Key"];
    [keyTF setDelegate:self];
    keyTF.text = key;
    [keyTF setBackgroundColor:[UIColor whiteColor]];
    [containerView addSubview:keyTF];
    [keyTF.layer setBorderColor:[UIColor darkGrayColor].CGColor];
    [keyTF.layer setBorderWidth:1];
    [keyTF mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(self.scrollView.mas_left).with.offset(5);
        make.top.equalTo(containerView.mas_top).with.offset(1);
        make.right.equalTo(self.scrollView.mas_centerX).with.offset(-7);
        make.height.equalTo(@32);
    }];
    
    
    UITextField *valueTF = [[UITextField alloc] init];
    [valueTF setPlaceholder:@"Value"];
    [valueTF setDelegate:self];
    valueTF.text = value;
    [valueTF setBackgroundColor:[UIColor whiteColor]];
    [containerView addSubview:valueTF];
    [valueTF.layer setBorderColor:[UIColor darkGrayColor].CGColor];
    [valueTF.layer setBorderWidth:1];
    [valueTF mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(keyTF.mas_right).with.offset(5);
        make.top.equalTo(containerView.mas_top).with.offset(1);
        make.right.equalTo(self.view.mas_right).with.offset(-7);
        make.height.equalTo(@32);
    }];
    
    self.yAxes = self.yAxes + 39;
    
    [self.scrollView setContentSize:CGSizeMake([[UIScreen mainScreen] bounds].size.width - 30, self.yAxes + 250)];
}

-(void)setUpConstraints
{
    [logoImgV mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.equalTo(self.view.mas_left).with.offset(-50);
        make.right.equalTo(self.view.mas_right).with.offset(70);
        make.top.equalTo(self.view.mas_top).with.offset([UIScreen mainScreen].bounds.size.height/2 - 30);
        make.bottom.equalTo(self.view.mas_bottom).with.offset(-([UIScreen mainScreen].bounds.size.height - 100));
        
    }];
    
    [self.addParamsBtn mas_makeConstraints:^(MASConstraintMaker *make){
        make.right.equalTo(self.view.mas_right).with.offset(-5);
        make.top.equalTo(self.view.mas_top).with.offset(8);
        make.height.equalTo(@30);
        make.width.equalTo(@60);
    }];
    
    [self.resetParamsBtn mas_makeConstraints:^(MASConstraintMaker *make){
        make.right.equalTo(self.addParamsBtn.mas_left).with.offset(-10);
        make.top.equalTo(self.view.mas_top).with.offset(8);
        make.height.equalTo(@30);
        make.width.equalTo(@100);
    }];
    
    [self.sendBtn mas_makeConstraints:^(MASConstraintMaker *make){
        make.right.equalTo(self.view.mas_right).with.offset(-5);
        make.top.equalTo(self.resetParamsBtn.mas_bottom).with.offset(10);
        make.height.equalTo(@30);
        make.width.equalTo(@60);
    }];

    
    [self.scrollView mas_makeConstraints:^(MASConstraintMaker *make){
        make.right.equalTo(self.view.mas_right).with.offset(-2);
        make.left.equalTo(self.view.mas_left).with.offset(2);
        make.top.equalTo(self.sendBtn.mas_bottom).with.offset(10);
        make.bottom.equalTo(self.view.mas_bottom).with.offset(-2);
    }];
    
}

@end
