
/**
 * native console logger for ios
 **/
// (function() {
//     var isIOS = (/iphone|ipad|ipod/i).test(window.navigator.userAgent.toLowerCase());
//     if (isIOS) {
//         console = {};
//         console.log = function(log) {
//             log = "[POKKT-JS]" + log;
//             var iframe = document.createElement("IFRAME");
//             iframe.setAttribute("src", "console-log://" + log);
//             document.documentElement.appendChild(iframe);
//             iframe.parentNode.removeChild(iframe);
//             iframe = null;
//         };
//     }
// } ());


/**
 * pokkt-osvad bridge functionalities
 **/
(function() {

    //\\//\\//\\//\\//\\//\\//\\// NATIVE \\//\\//\\//\\//\\//\\//\\//\\

    var notifyNative = function(operation, params) {
        var command = operation + "?params=" + params;

        var iframe = document.createElement("IFRAME");
        iframe.setAttribute("src", "osvad://" + command);
        document.documentElement.appendChild(iframe);
        iframe.parentNode.removeChild(iframe);
        iframe = null;
    };


    /**
     * helpers
     **/

    var isElementInViewport = function(el) {
        var rect = el.getBoundingClientRect();
        return (
            rect.top >= 0 &&
            rect.left >= 0 &&
            rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
            rect.right <= (window.innerWidth || document.documentElement.clientWidth)
        );
    };

    var updateVisibility = function() {
        if (agentOSVAD) {
            var newVisibility = isElementInViewport(agentOSVAD);
            if (newVisibility != isOSVADAgentVisible) {
                isOSVADAgentVisible = newVisibility;

                // visibility changed, notify
                //notifySDK("setAgentVisible", "" + isOSVADAgentVisible);
            }
        }
    };


    /**
     * bridge
     **/
    
    var bridge = window.osvadBridge = {};

    var agentOSVAD;
    var isOSVADAgentVisible = false;

    bridge.remove = function() {
        if (document.body.contains(agentOSVAD)) {
            document.body.removeChild(agentOSVAD);
        }
    };

    bridge.setAgentSize = function(width, height) {
        console.log("bridge.setAgentSize");

        var element = document.getElementsByTagName('body')[0];
        var style = window.getComputedStyle(element);
        var marginLeft = parseInt(style.marginLeft);
        var marginRight = parseInt(style.marginRight);
    
        var adjustedWidth = width - marginLeft - marginRight;
        console.log("marginLeft: " + marginLeft + ", marginRight: " + marginRight + ", adjustedWidth: " + adjustedWidth);
    
        agentOSVAD.style.width = adjustedWidth;
        agentOSVAD.style.height = height;
        //updateAgentBounds();
    };

    bridge.updateAgentBounds = function() {
        console.log("bridge.updateAgentBounds");
        if (agentOSVAD) {
            var rect = agentOSVAD.getBoundingClientRect();
            console.log("agent rect: " + rect);
            notifyNative("updateAgentBounds", JSON.stringify(rect));
        }
    };

    bridge.setAgentBGColor = function(value) {
        console.log("bridge.setAgentBGColor");
        if (agentOSVAD) {
            agentOSVAD.style.backgroundColor = value;
        }
    };
    
    bridge.findLocationForAd = function() {
        console.log("bridge.findLocationForAd");
        osvadBridge.setAgentBGColor("#FF00FF");
        //setAgentSize(30, 1); // initial
        osvadBridge.updateAgentBounds();
    }

    bridge.initPokktOSVAD = function() {
        console.log("bridge.initPokktOSVAD");
        // locate an element with id "osvad", it has to be of type "CENTER"
        agentOSVAD = document.getElementById("osvad");
    
        // if not found, create a new one and put it in the host page
        if (!agentOSVAD || agentOSVAD.nodeName != "CENTER") {
            agentOSVAD = document.createElement("center");
            agentOSVAD.id = "osvad";
            document.body.appendChild(agentOSVAD);
            console.log("element osvad is created!");
        } else {
            console.log("element osvad is already available!");
        }
    
        // this will also ensure the SDK that script is ready
        notifyNative("pokktOSVADInitDone", "");
    };

    bridge.handler = function () {
        //updateVisibility();
        if (agentOSVAD && isOSVADAgentVisible) {
            updateAgentBounds();
        }
    };
            
} ());

// attach listeners
if (window.addEventListener) {
    addEventListener('scroll', osvadBridge.handler, false);
    addEventListener('resize', osvadBridge.handler, false);
} else if (window.attachEvent) {
    attachEvent('onscroll', osvadBridge.handler);
    attachEvent('onresize', osvadBridge.handler);
}

function initOSVAD() {
    osvadBridge.initPokktOSVAD();
}
